@@ -1,4 +1,3 @@
-"""Window used for game installers"""
 import os
 import time
 import webbrowser
@@ -14,7 +13,7 @@ from lutris.gui.dialogs import (
     NoInstallerDialog, DirectoryDialog, InstallerSourceDialog, QuestionDialog
 )
 from lutris.gui.widgets.download_progress import DownloadProgressBox
-from lutris.gui.widgets.common import FileChooserEntry, InstallerLabel
+from lutris.gui.widgets.common import FileChooserEntry
 from lutris.gui.widgets.installer import InstallerPicker
 from lutris.gui.widgets.log_text_view import LogTextView
 from lutris.gui.widgets.window import BaseApplicationWindow
@@ -50,10 +49,10 @@ class InstallerWindow(BaseApplicationWindow):
         self.log_buffer = None
         self.log_textview = None
 
-        self.title_label = InstallerLabel()
+        self.title_label = Gtk.Label()
         self.vbox.add(self.title_label)
 
-        self.status_label = InstallerLabel()
+        self.status_label = Gtk.Label()
         self.status_label.set_max_width_chars(80)
         self.status_label.set_property("wrap", True)
         self.status_label.set_selectable(True)
@@ -72,7 +71,7 @@ class InstallerWindow(BaseApplicationWindow):
         self.vbox.pack_start(action_buttons_alignment, False, True, 0)
 
         self.cancel_button = Gtk.Button.new_with_mnemonic("C_ancel")
-        self.cancel_button.set_tooltip_text("Abort and revert the installation")
+        self.cancel_button.set_tooltip_text("Abort and revert the " "installation")
         self.cancel_button.connect("clicked", self.cancel_installation)
         self.action_buttons.add(self.cancel_button)
 
@@ -85,15 +84,12 @@ class InstallerWindow(BaseApplicationWindow):
 
         self.continue_handler = None
 
-        # check if installer is local or online
-        if system.path_exists(self.installer_file):
-            self.get_scripts(local_script=True)
-        else:
-            self.title_label.set_markup("Waiting for response from %s" % (settings.SITE_URL))
-            self.add_spinner()
-            self.widget_box.show()
-            self.title_label.show()
-            self.get_scripts(local_script=False)
+        self.get_scripts()
+
+        self.title_label.set_markup("Waiting for response from %s" % (settings.SITE_URL))
+        self.add_spinner()
+        self.widget_box.show()
+        self.title_label.show()
 
         self.present()
 
@@ -104,8 +100,9 @@ class InstallerWindow(BaseApplicationWindow):
         self.action_buttons.add(button)
         return button
 
-    def get_scripts(self, local_script=False):
-        if local_script:
+    def get_scripts(self):
+        if system.path_exists(self.installer_file):
+            # local script
             self.on_scripts_obtained(interpreter.read_script(self.installer_file))
         else:
             jobs.AsyncCall(
@@ -344,9 +341,10 @@ class InstallerWindow(BaseApplicationWindow):
         """Ask the user to do insert a CD-ROM."""
         time.sleep(0.3)
         self.clean_widgets()
-        label = InstallerLabel(message)
-        label.show()
+        label = Gtk.Label(label=message)
+        label.set_use_markup(True)
         self.widget_box.add(label)
+        label.show()
 
         buttons_box = Gtk.Box()
         buttons_box.show()
@@ -434,6 +432,10 @@ class InstallerWindow(BaseApplicationWindow):
         self.play_button.show()
         self.close_button.grab_focus()
         self.close_button.show()
+        game_data = pga.get_game_by_field(self.game_slug, "slug")
+
+        game = Game(game_data["id"])
+        game.save(metadata_only=True)
         if not self.is_active():
             self.set_urgency_hint(True)  # Blink in taskbar
             self.connect("focus-in-event", self.on_window_focus)
@@ -517,8 +519,11 @@ class InstallerWindow(BaseApplicationWindow):
 
     def set_message(self, message):
         """Display a message."""
-        label = InstallerLabel()
+        label = Gtk.Label()
         label.set_markup("<b>%s</b>" % add_url_tags(message))
+        label.set_max_width_chars(80)
+        label.set_property("wrap", True)
+        label.set_alignment(0, 0)
         label.show()
         self.widget_box.pack_start(label, False, False, 18)
 
