@@ -25,17 +25,20 @@ LIBRETRO_CORES = [
     ("Dolphin (Nintendo Wii/Gamecube)", "dolphin", "Nintendo Wii/Gamecube"),
     ("EightyOne (Sinclair ZX81)", "81", "Sinclair ZX81"),
     ("FB Alpha (Arcade)", "fbalpha", "Arcade"),
+    ("FB Alpha (Capcom Play System 1)", "fbalpha2012_cps1", "Arcade"),
+    ("FB Alpha (Capcom Play System 2)", "fbalpha2012_cps2", "Arcade"),
+    ("FB Alpha (Capcom Play System 3)", "fbalpha2012_cps3", "Arcade"),
+    ("FB Alpha (SNK Neo Geo)", "fbalpha2012_neogeo", "Arcade"),
+    ("FBNeo (Arcade)", "fbneo", "Arcade"),
     ("FCEUmm (Nintendo Entertainment System)", "fceumm", "Nintendo NES"),
+    ('Flycast (Sega Dreamcast)', 'flycast', 'Sega Dreamcast'),
+    ('Flycast WinCE (Sega Dreamcast)', 'flycast_wince', 'Sega Dreamcast'),
     ("fMSX (MSX/MSX2/MSX2+)", "fmsx", "MSX/MSX2/MSX2+"),
     ("FreeJ2ME (J2ME)", "freej2me", "J2ME"),
     ("Fuse (ZX Spectrum)", "fuse", "Sinclair ZX Spectrum"),
     ("Gambatte (Game Boy Color)", "gambatte", "Nintendo Game Boy Color"),
     ("Gearboy (Game Boy Color)", "gearboy", "Nintendo Game Boy Color"),
-    (
-        "Gearsystem (Sega Maste System/Gamegear)",
-        "gearsystem",
-        "Sega Maste System/Gamegear",
-    ),
+    ("Gearsystem (Sega Maste System/Gamegear)", "gearsystem", "Sega Maste System/Gamegear"),
     ("Genesis Plus GX (Sega Genesis)", "genesis_plus_gx", "Sega Genesis"),
     ("Handy (Atari Lynx)", "handy", "Atari Lynx"),
     ("Hatari (Atari ST/STE/TT/Falcon)", "hatari", "Atari ST/STE/TT/Falcon"),
@@ -45,22 +48,16 @@ LIBRETRO_CORES = [
     ("MAME (Arcade)", "mame", "Arcade"),
     ("Mednafen GBA (Game Boy Advance)", "mednafen_gba", "Nintendo Game Boy Advance"),
     ("Mednafen NGP (SNK Neo Geo Pocket)", "mednafen_ngp", "SNK Neo Geo Pocket"),
-    (
-        "Mednafen PCE FAST (TurboGrafx-16)",
-        "mednafen_pce_fast",
-        "NEC PC Engine (TurboGrafx-16)",
-    ),
+    ("Mednafen PCE (TurboGrafx-16)", "mednafen_pce", "NEC PC Engine (TurboGrafx-16)"),
+    ("Mednafen PCE FAST (TurboGrafx-16)", "mednafen_pce_fast", "NEC PC Engine (TurboGrafx-16)"),
     ("Mednafen PCFX (NEC PC-FX)", "mednafen_pcfx", "NEC PC-FX"),
     ("Mednafen Saturn (Sega Saturn)", "mednafen_saturn", "Sega Saturn"),
-    (
-        "Mednafen SGX (NEC PC Engine SuperGrafx)",
-        "mednafen_supergrafx",
-        "NEC PC Engine (SuperGrafx)",
-    ),
+    ("Mednafen SGX (NEC PC Engine SuperGrafx)", "mednafen_supergrafx", "NEC PC Engine (SuperGrafx)"),
     ("Mednafen WSWAN (Bandai WonderSwan)", "mednafen_wswan", "Bandai WonderSwan"),
     ("Mednafen PSX (Sony Playstation)", "mednafen_psx", "Sony PlayStation"),
     ("Mednafen PSX OpenGL (Sony Playstation)", "mednafen_psx_hw", "Sony PlayStation"),
     ("Mesen (Nintendo Entertainment System)", "mesen", "Nintendo NES"),
+    ("Mesen-S (Super Nintendo)", "mesen-s", "Nintendo SNES"),
     ("mGBA (Game Boy Advance)", "mgba", "Nintendo Game Boy Advance"),
     ("Mupen64Plus (Nintendo 64)", "mupen64plus", "Nintendo N64"),
     ("Nestopia (Nintendo Entertainment System)", "nestopia", "Nintendo NES"),
@@ -70,15 +67,20 @@ LIBRETRO_CORES = [
     ("ParaLLEl N64 (Nintendo 64)", "parallel_n64", "Nintendo N64"),
     ("PCSX Rearmed (Sony Playstation)", "pcsx_rearmed", "Sony PlayStation"),
     ("PicoDrive (Sega Genesis)", "picodrive", "Sega Genesis"),
+    ("Play! (Sony Playstation 2)", "play", "Sony PlayStation 2"),
     ("Portable SHARP X68000 Emulator (SHARP X68000)", "px68k", "Sharp X68000"),
     ("PPSSPP (PlayStation Portable)", "ppsspp", "Sony PlayStation Portable"),
     ("ProSystem (Atari 7800)", "prosystem", "Atari 7800"),
+    ("QUASI88 (NEC PC-8801)", "quasi88", "NEC PC-8801"),
     ("Redream (Sega Dreamcast)", "redream", "Sega Dreamcast"),
     ("Reicast (Sega Dreamcast)", "reicast", "Sega Dreamcast"),
+    ("Reicast WinCE (Sega Dreamcast)", "reicast_wince", "Sega Dreamcast"),
     ("RPG Maker 2000/2003 (EasyRPG)", "easyrpg", "RPG Maker 2000/2003 Game Engine"),
     ("Snes9x (Super Nintendo)", "snes9x", "Nintendo SNES"),
     ("Snes9x2010 (Super Nintendo)", "snes9x2010", "Nintendo SNES"),
     ("Stella (Atari 2600)", "stella", "Atari 2600"),
+    ("Stella 2014 (Atari 2600)", "stella2014", "Atari 2600"),
+    ("Tic-80 (Tic-80)", "tic80", "TIC-80"),
     ("Uzem (Uzebox)", "uzem", "Uzebox"),
     ("VecX (Vectrex)", "vecx", "Vectrex"),
     ("Yabause (Sega Saturn)", "yabause", "Sega Saturn"),
@@ -86,8 +88,11 @@ LIBRETRO_CORES = [
     ("VBA-M (Game Boy Advance)", "vbam", "Nintendo Game Boy Advance"),
     ("Virtual Jaguar (Atari Jaguar)", "virtualjaguar", "Atari Jaguar"),
     ("VICE (Commodore 128)", "vice_x128", "Commodore 128"),
+    ("VICE (Commodore CBM-II)", "vice_xcbm2", "Commodore CBM-II"),
+    ("VICE (Commodore Pet)", "vice_xpet", "Commodore Pet"),
     ("VICE (Commodore 16/Plus/4)", "vice_xplus4", "Commodore 16/Plus/4"),
     ("VICE (Commodore 64)", "vice_x64", "Commodore 64"),
+    ("VICE (Commodore 64)(Cycle-Exact)", "vice_x64sc", "Commodore 64"),
     ("VICE (Commodore VIC-20)", "vice_xvic", "Commodore VIC-20"),
 ]
 
